pub struct MoveAuthenticator { /* private fields */ }Expand description
MoveAuthenticator is a GenericSignature variant that enables a new method of authentication through Move code. This function represents the data received by the Move authenticate function during the Account Abstraction authentication flow.
Implementations
Sourceimpl MoveAuthenticator
impl MoveAuthenticator
Sourcepub fn new_v1(
call_args: Vec<CallArg>,
type_arguments: Vec<TypeInput>,
object_to_authenticate: CallArg,
) -> Self
pub fn new_v1( call_args: Vec<CallArg>, type_arguments: Vec<TypeInput>, object_to_authenticate: CallArg, ) -> Self
Creates a new MoveAuthenticator of version 1.
Sourcepub fn digest(&self) -> MoveAuthenticatorDigest
pub fn digest(&self) -> MoveAuthenticatorDigest
Computes the digest of the MoveAuthenticator.
Sourcepub fn address(&self) -> IotaResult<IotaAddress>
pub fn address(&self) -> IotaResult<IotaAddress>
Returns the address of the MoveAuthenticator.
Sourcepub fn type_arguments(&self) -> &Vec<TypeInput>
pub fn type_arguments(&self) -> &Vec<TypeInput>
Returns the type arguments of the MoveAuthenticator.
Sourcepub fn object_to_authenticate(&self) -> &CallArg
pub fn object_to_authenticate(&self) -> &CallArg
Returns the object to authenticate of the MoveAuthenticator.
Sourcepub fn object_to_authenticate_components(
&self,
) -> UserInputResult<(ObjectID, Option<SequenceNumber>, Option<ObjectDigest>)>
pub fn object_to_authenticate_components( &self, ) -> UserInputResult<(ObjectID, Option<SequenceNumber>, Option<ObjectDigest>)>
Returns the components of the object to authenticate.
Sourcepub fn input_objects(&self) -> Vec<InputObjectKind>
pub fn input_objects(&self) -> Vec<InputObjectKind>
Returns all input objects used by the MoveAuthenticator, including those from the object to authenticate.
Sourcepub fn receiving_objects(&self) -> Vec<ObjectRef> ⓘ
pub fn receiving_objects(&self) -> Vec<ObjectRef> ⓘ
Returns all receiving objects used by the MoveAuthenticator.
Returns all shared input objects used by the MoveAuthenticator, including those from the object to authenticate.
Sourcepub fn validity_check(&self, config: &ProtocolConfig) -> UserInputResult
pub fn validity_check(&self, config: &ProtocolConfig) -> UserInputResult
Validity check for MoveAuthenticator.