Struct MoveAuthenticatorV1
pub struct MoveAuthenticatorV1 { /* private fields */ }Expand description
Version 1 of the MoveAuthenticator.
Implementations
impl MoveAuthenticatorV1
impl MoveAuthenticatorV1
pub fn new_with_immutable_account_object(
call_args: Vec<Input>,
type_args: Vec<TypeTag>,
object_to_authenticate: ObjectReference,
) -> MoveAuthenticatorV1
pub fn new_with_immutable_account_object( call_args: Vec<Input>, type_args: Vec<TypeTag>, object_to_authenticate: ObjectReference, ) -> MoveAuthenticatorV1
Create a new move authenticator with an immutable object.
Create a new move authenticator with a shared object.
pub fn address(&self) -> Address
pub fn address(&self) -> Address
Returns the address of the object being authenticated, which acts as the sender of the transaction.
pub fn call_args(&self) -> &[Input]
pub fn call_args(&self) -> &[Input]
Returns the input objects or primitive values passed to the authenticate function.
pub fn type_args(&self) -> &[TypeTag]
pub fn type_args(&self) -> &[TypeTag]
Returns the type arguments for the Move authenticate function.
pub fn object_to_authenticate(&self) -> &Input
pub fn object_to_authenticate(&self) -> &Input
Returns the object that is being authenticated (the account/sender).